# -*- python -*-
#
# Copyright 2018, 2019, 2020 Xingeng Chen
# Copyright 2016, 2017 Liang Chen
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#   http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import sys
from setuptools import find_packages, setup

class SetupConfig(object):
    CONFIG_HUB = {
        2: {
            'install_requires': ['amqplib',],
        },
        3: {
            'install_requires': ['amqp',],
        },
    }
    def getConfig(self, py_ver=3):
        return self.CONFIG_HUB[py_ver]

setup_args = SetupConfig().getConfig(sys.version_info.major)
setup(**setup_args)
